@@ -1,6 +1,6 @@
 /*********************************************************************
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2008 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2010 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -123,7 +123,7 @@ struct arg_file
    int count;               /* Number of matching command line args*/
    const char **filename;   /* Array of parsed filenames  (eg: /home/foo.bar) */
    const char **basename;   /* Array of parsed basenames  (eg: foo.bar) */
-   const char **extension;  /* Array of parsed extensions (eg: bar) */
+   const char **extension;  /* Array of parsed extensions (eg: .bar) */
    };
 
 struct arg_date
